==> nif-0.2.0.crate: nif-0.2.0/src/blocks/mod.rs <==
mod ni_animation;
mod ni_main;
mod ni_particle;

pub use ni_animation::*;
pub use ni_main::*;
pub use ni_particle::*;

#[derive(Debug, PartialEq)]
pub enum Block {
    NiObjectNET(NiObjectNET),
    NiAvObject(NiAvObject),
    NiNode(NiNode),
    NiZBufferProperty(NiZBufferProperty),
    NiVertexColorProperty(NiVertexColorProperty),
    NiTriShape(NiTriShape),
    NiStringExtraData(NiStringExtraData),
    NiTexturingProperty(NiTexturingProperty),
    NiSourceTexture(NiSourceTexture),
    NiAlphaProperty(NiAlphaProperty),
    NiMaterialProperty(NiMaterialProperty),
    NiTriShapeData(NiTriShapeData),
    NiIntegerExtraData(NiIntegerExtraData),
    NiSpecularProperty(NiSpecularProperty),
    NiSwitchNode(NiSwitchNode),
    NiLODNode(NiLODNode),
    NiRangeLODData(NiRangeLODData),
    NiBillboardNode(NiBillboardNode),
    NiCollisionObject(NiCollisionObject),
    NiCollisionData(NiCollisionData),
    NiStencilProperty(NiStencilProperty),
    NiTimeController(NiTimeController),
    NiInterpController(NiInterpController),
    NiSingleInterpController(NiSingleInterpController),
    NiFloatInterpController(NiFloatInterpController),
    NiAlphaController(NiAlphaController),
    NiInterpolator(NiInterpolator),
    NiKeyBasedInterpolator(NiKeyBasedInterpolator),
    NiFloatInterpolator(NiFloatInterpolator),
    NiFloatData(NiFloatData),
    NiParticleSystem(NiParticleSystem),
    NiPSysEmitterCtlr(NiPSysEmitterCtlr),
    NiPSysUpdateCtlr(NiPSysUpdateCtlr),
    NiBoolInterpolator(NiBoolInterpolator),
    NiBoolData(NiBoolData),
    NiColorData(NiColorData),
    NiPSysData(NiPSysData),
    NiPSysAgeDeathModifier(NiPSysAgeDeathModifier),
    NiPSysBoxEmitter(NiPSysBoxEmitter),
    NiPSysSpawnModifier(NiPSysSpawnModifier),
    NiPSysGrowFadeModifier(NiPSysGrowFadeModifier),
    NiPSysColorModifier(NiPSysColorModifier),
    NiPSysRotationModifier(NiPSysRotationModifier),
    NiPSysPositionModifier(NiPSysPositionModifier),
    NiPSysBoundUpdateModifier(NiPSysBoundUpdateModifier),
    NiPSysGravityModifier(NiPSysGravityModifier),
    NiPSysColliderManager(NiPSysColliderManager),
    NiPSysPlanarCollider(NiPSysPlanarCollider),
    NiTransformController(NiTransformController),
    NiTransformData(NiTransformData),
    NiTransformInterpolator(NiTransformInterpolator),
}

==> nif-0.4.0.crate: nif-0.4.0/src/blocks/mod.rs <==
mod ni_animation;
mod ni_main;
mod ni_particle;

pub use ni_animation::*;
pub use ni_main::*;
pub use ni_particle::*;

#[allow(clippy::clippy::large_enum_variant)]
#[derive(Debug, PartialEq)]
pub enum Block {
    NiObjectNET(NiObjectNET),
    NiAvObject(NiAvObject),
    NiNode(NiNode),
    NiZBufferProperty(NiZBufferProperty),
    NiVertexColorProperty(NiVertexColorProperty),
    NiTriShape(NiTriShape),
    NiStringExtraData(NiStringExtraData),
    NiTexturingProperty(NiTexturingProperty),
    NiSourceTexture(NiSourceTexture),
    NiAlphaProperty(NiAlphaProperty),
    NiMaterialProperty(NiMaterialProperty),
    NiTriShapeData(NiTriShapeData),
    NiIntegerExtraData(NiIntegerExtraData),
    NiSpecularProperty(NiSpecularProperty),
    NiSwitchNode(NiSwitchNode),
    NiLODNode(NiLODNode),
    NiRangeLODData(NiRangeLODData),
    NiBillboardNode(NiBillboardNode),
    NiCollisionObject(NiCollisionObject),
    NiCollisionData(NiCollisionData),
    NiStencilProperty(NiStencilProperty),
    NiTimeController(NiTimeController),
    NiInterpController(NiInterpController),
    NiSingleInterpController(NiSingleInterpController),
    NiFloatInterpController(NiFloatInterpController),
    NiAlphaController(NiAlphaController),
    NiInterpolator(NiInterpolator),
    NiKeyBasedInterpolator(NiKeyBasedInterpolator),
    NiFloatInterpolator(NiFloatInterpolator),
    NiFloatData(NiFloatData),
    NiParticleSystem(NiParticleSystem),
    NiPSysEmitterCtlr(NiPSysEmitterCtlr),
    NiPSysUpdateCtlr(NiPSysUpdateCtlr),
    NiBoolInterpolator(NiBoolInterpolator),
    NiBoolData(NiBoolData),
    NiColorData(NiColorData),
    NiPSysData(NiPSysData),
    NiPSysAgeDeathModifier(NiPSysAgeDeathModifier),
    NiPSysBoxEmitter(NiPSysBoxEmitter),
    NiPSysSpawnModifier(NiPSysSpawnModifier),
    NiPSysGrowFadeModifier(NiPSysGrowFadeModifier),
    NiPSysColorModifier(NiPSysColorModifier),
    NiPSysRotationModifier(NiPSysRotationModifier),
    NiPSysPositionModifier(NiPSysPositionModifier),
    NiPSysBoundUpdateModifier(NiPSysBoundUpdateModifier),
    NiPSysGravityModifier(NiPSysGravityModifier),
    NiPSysColliderManager(NiPSysColliderManager),
    NiPSysPlanarCollider(NiPSysPlanarCollider),
    NiTransformController(NiTransformController),
    NiTransformData(NiTransformData),
    NiTransformInterpolator(NiTransformInterpolator),
    NiColorExtraData(NiColorExtraData),
    NiFlipController(NiFlipController),
    NiFloatExtraData(NiFloatExtraData),
    NiTextureTransformController(NiTextureTransformController),
    NiPixelData(NiPixelData),
    NiVisController(NiVisController),
    NiTextureEffect(NiTextureEffect),
    NiSourceCubeMap(NiSourceCubeMap),
    NiShadeProperty(NiShadeProperty),
    NiGeomMorpherController(NiGeomMorpherController),
    NiMorphData(NiMorphData),
    NiDitherProperty(NiDitherProperty),
    NiMaterialColorController(NiMaterialColorController),
    NiPoint3Interpolator(NiPoint3Interpolator),
    NiPosData(NiPosData),
    NiSkinInstance(NiSkinInstance),
    NiSkinData(NiSkinData),
    NiSkinPartition(NiSkinPartition),
    NiPathInterpolator(NiPathInterpolator),
    NiTriStrips(NiTriStrips),
    NiTriStripsData(NiTriStripsData),
    NiPSysMeshEmitter(NiPSysMeshEmitter),
    NiPSysCylinderEmitter(NiPSysCylinderEmitter),
    NiPSysSphereEmitter(NiPSysSphereEmitter),
    NiPSysResetOnLoopCtlr(NiPSysResetOnLoopCtlr),
    NiDirectionalLight(NiDirectionalLight),
    NiFloatsExtraData(NiFloatsExtraData),
}
